pub struct IndentOptions<'a, 'b> {
pub indentor: Option<&'a str>,
pub exclude: &'b [(u32, u32)],
}Fields
indentor: Option<&'a str>MagicString will guess the indentor from lines of the source if passed None.
exclude: &'b [(u32, u32)]The reason I use [u32; 2] instead of (u32, u32) to represent a range of text is that
I want to emphasize that the [u32; 2] is the closed interval, which means both the start
and the end are included in the range.